@@ -7,14 +7,13 @@ to define the button parameters in your config.
 
 Configuration parameters:
     button_next: mouse button to play the next entry (default None)
-    button_next_player: (Experimental) mouse button to switch next player in list (Same status as top player) (default None)
-    button_prev_player: (Experimental) mouse button to switch previous player in list (Same status as top player) (default None)
+    button_next_player: mouse button to switch next player in list (Same status as top player) (default None)
+    button_prev_player: mouse button to switch previous player in list (Same status as top player) (default None)
     button_previous: mouse button to play the previous entry (default None)
     button_stop: mouse button to stop the player (default None)
     button_switch_to_top_player: mouse button to switch to top player (default None)
     button_toggle: mouse button to toggle between play and pause mode (default 1)
     cache_timeout: time (s) between Position update (default 0.5)
-    format: see placeholders below
     format: display format for this module
         (default '[{artist} - ][{title}] {previous} {toggle} {next}')
     format_none: define output if no player is running (default 'no player running')
@@ -24,24 +23,25 @@ Configuration parameters:
     icon_previous: specify icon for previous button (default u'\u25c3')
     icon_stop: specify icon for stop button (default u'\u25a1')
     max_width: maximum status length (default None)
-    player_hide_non_canplay: Experimental. Used to hide chrome/chromium players on idle state. Add 'chromium' into list and try. (default [])
     player_priority: priority of the players.
         Keep in mind that the state has a higher priority than
         player_priority. So when player_priority is "[mpd, bomi]" and mpd is
         paused and bomi is playing than bomi wins. (default [])
+    replacements: specify a list/dict of string placeholders to modify (default None)
     state_pause: specify icon for pause state (default u'\u25eb')
     state_play: specify icon for play state (default u'\u25b7')
     state_stop: specify icon for stop state (default u'\u25a1')
 
 Format placeholders:
     {album} album name
-    {artist} artiste name (first one)
+    {artist} artist name (first one)
     {length} time duration of the song
     {player} show name of the player
     {player_shortname} show name of the player from busname (usually command line name)
     {state} playback status of the player
     {time} played time of the song
     {title} name of the song
+    {tracknumber} track number of the song
     {nowplaying} now playing field provided by VLC for stream info
 
 Button placeholders:
@@ -61,7 +61,8 @@ Color options:
 
 Requires:
     mpris2: Python usable definiton of MPRIS2
-    dbus: Python bindings for dbus
+    dbus-python: Python bindings for dbus
+    PyGObject: Python bindings for GObject Introspection
 
 Tested players:
     bomi: powerful and easy-to-use gui multimedia player based on mpv
@@ -150,7 +151,6 @@ class Player:
         self._player_shortname = name_from_id
         self._dPlayer = dPlayer(dbus_interface_info={"dbus_uri": player_id})
         self._full_name = f"{self._identity} {self._identity_index}"
-        self._hide_non_canplay = self._player_shortname in self.parent.player_hide_non_canplay
 
         self._placeholders = {
             "player": self._identity,
@@ -280,8 +280,16 @@ class Player:
 
             self._metadata["length"] = self._get_time_str(metadata.get(Metadata_Map.LENGTH))
 
+            # we are converting the attribute name to lowercase because although the spec
+            # says it's `xesam:trackNumber`, VLC exposes it as `xesam:tracknumber`
+            self._metadata["tracknumber"] = metadata.get(Metadata_Map.TRACK_NUMBER.lower())
+
             self._metadata["nowplaying"] = metadata.get("vlc:nowplaying", None)
 
+            for x in self.parent.replacements_init:
+                if x in self._metadata:
+                    self._metadata[x] = self.parent.py3.replace(self._metadata[x], x)
+
         if not self._metadata.get("title"):
             self._metadata["title"] = "No Track"
 
@@ -346,7 +354,7 @@ class Player:
 
     @property
     def hide(self):
-        return self._hide_non_canplay and not self._can.get("CanPlay")
+        return not self._can.get("CanPlay")
 
     @property
     def id(self):
@@ -380,13 +388,24 @@ class Py3status:
     icon_previous = "\u25c3"
     icon_stop = "\u25a1"
     max_width = None
-    player_hide_non_canplay = []
     player_priority = []
+    replacements = None
     state_pause = "\u25eb"
     state_play = "\u25b7"
     state_stop = "\u25a1"
 
+    class Meta:
+        deprecated = {
+            'remove': [
+                {
+                    'param': 'player_hide_non_canplay',
+                    'msg': 'obsolete because we now hide all non canplay players',
+                },
+            ],
+        }
+
     def post_config_hook(self):
+        self.replacements_init = self.py3.get_replacements_list(self.format)
         self._name_owner_change_match = None
         self._kill = False
         self._mpris_players: dict[Player] = {}
@@ -400,6 +419,7 @@ class Py3status:
             "artist": None,
             "length": None,
             "title": None,
+            "tracknumber": None,
             "nowplaying": None,
             "time": None,
             "state": None,
@@ -470,7 +490,7 @@ class Py3status:
         self._color_inactive = self.py3.COLOR_CONTROL_INACTIVE or self.py3.COLOR_BAD
 
         self._format_contains_metadata = False
-        self._metadata_keys = ["album", "artist", "title", "nowplaying", "length"]
+        self._metadata_keys = ["album", "artist", "title", "nowplaying", "length", "tracknumber"]
         for key in self._metadata_keys:
             if self.py3.format_contains(self.format, key):
                 self._format_contains_metadata = True
@@ -483,7 +503,7 @@ class Py3status:
                 self._format_contains_control_buttons = True
                 self._used_can_properties.append(value["clickable"])
 
-        if len(self.player_hide_non_canplay) and "CanPlay" not in self._used_can_properties:
+        if "CanPlay" not in self._used_can_properties:
             self._used_can_properties.append("CanPlay")
 
         self._format_contains_time = self.py3.format_contains(self.format, "time")
@@ -566,7 +586,7 @@ class Py3status:
         name_from_id = player_id_parts_list[3]
 
         identity = None
-        if name_from_id != "chromium":
+        if name_from_id not in ["chromium", "kdeconnect"]:
             identity = self._identity_cache.get(name_from_id)
 
         if not identity:
